@@ -20,7 +20,10 @@ class MultiTenantMixin(TenantMixin):
     def __str__(self):
         return self.schema_name
 
+    @property
+    def codename(self):
+        return self.id
+
     def is_leading(self):
         """Check if it's main tenant."""
-
         return not self.tenant_id
